
	
	
	
	
	
	
	
;==============================================================================;
; PLAYER_START
; Called by the BIOS if one of the Start buttons is pressed while the player
; has enough credits (or if the the time runs out on the title menu?).
; We're not using this in this demo.
	even
PLAYER_START:
	move.b	d0,REG_DIPSW		; kick the watchdog
	rts

;==============================================================================;
; DEMO_END
; Called by the BIOS when the Select button is pressed; ends the demo early.

DEMO_END:
	; if necessary, store any items in the (MVS) backup RAM.
	rts

;==============================================================================;
; COIN_SOUND
; Called by the BIOS when a coin is inserted; should play a coin drop sound.
; We don't actually do anything here since this isn't meant to take coins.

COIN_SOUND:
	; Send a sound code
	rts

;==============================================================================;
; VBlank
; VBlank interrupt, run things we want to do every frame.

VBlank:
	; check if the BIOS wants to run its vblank
	btst	#7,BIOS_SYSTEM_MODE
	bne		.gamevbl
	; run BIOS vblank
	jmp		SYSTEM_INT1

	; run the game's vblank
.gamevbl
	movem.l d0-d7/a0-a6,-(sp)	; save registers
	move.w	#4,LSPC_IRQ_ACK		; acknowledge the vblank interrupt
	move.b	d0,REG_DIPSW		; kick the watchdog

	; do things in vblank

	ifd VblankCount
		addq.b #1,VblankCount
	endif
	
	
.endvbl:
	jsr		SYSTEM_IO			; "Call SYSTEM_IO every 1/60 second."
	jsr		MESS_OUT			; Puzzle Bobble calls MESS_OUT just after SYSTEM_IO
	move.b	#0,flag_VBlank		; clear vblank flag so waitVBlank knows to stop
	movem.l (sp)+,d0-d7/a0-a6	; restore registers
	rte

;==============================================================================;
; IRQ2
; Level 2/timer interrupt, unused here. You could use it for effects, though.

IRQ2:
	move.w	#2,LSPC_IRQ_ACK		; ack. interrupt #2 (HBlank)
	move.b	d0,REG_DIPSW		; kick watchdog
	rte

;==============================================================================;
; IRQ3
; Level 3 IRQ, unused here. Might be used for something else on CD, though.
; (More research needed)

IRQ3:
	move.w  #1,LSPC_IRQ_ACK		; acknowledge interrupt 3
	move.b	d0,REG_DIPSW		; kick watchdog
	rte


;==============================================================================;
; [Palettes]
NUM_PALETTES	equ 2		; used in palette loading loop

paletteData:
	; Palette Set $00 (Fix/Spr)
	dc.w	$8000			; reference color, must be $8000 black
	dc.w	$7FFF			; White
	dc.w	$0007			; normal Black
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	dc.w	$0000
	;--------------------------------------------------------------------------;
	; Palette Set $01 (Fix/Spr)
	dc.w	$0000			; transparent color
	dc.w	$0FF0			; Red
	dc.w	$0FF0			; Black
	dc.w	$0FF0
	dc.w	$0FF0
	dc.w	$0FF0			;DLLLRRRRGGGGBBBB = Dark Bit / Least Significant bits / Red Green Blue
	dc.w	$0FF0
	dc.w	$0FF0
	dc.w	$0FF0
	dc.w	$0FF0
	dc.w	$0FF0
	dc.w	$0FF0
	dc.w	$0FF0
	dc.w	$0FF0
	dc.w	$0FF0
	dc.w	$0FF0

	
	
	even
	dc.w 0	;make sure we end on an even byte!
	
;==============================================================================;
; Neo-Geo User RAM template
;==============================================================================;
; Note: This isn't using vlink; this will be replaced in the future.
;==============================================================================;
; normal RAM begins at $100000
;RAMBEGIN equ $100000

; USER RAM (begins at $100000)
USER_RAM equ $100000

;==============================================================================;
; [freemlib RAM usage]
; If you're not using the freemlib in your project, feel free to nuke this part.
; You really should have some sort of VBlank flag, though. And if you're using
; the VBlank/INT2/IRQ2/whatever, a flag for that as well.

flag_VBlank equ USER_RAM   ; (byte) vblank flag
flag_HBlank equ USER_RAM+1 ; (byte) hblank flag

;==============================================================================;
; you'll want to add your own variables to this, of course.
